Code for generating human-readable reports from test results. Each reporter takes a collection of test results as input and should produce some output, depending on the report type.
Code for generating human-readable reports from test results. Each reporter takes a collection of test results as input and should produce some output, depending on the report type.
(handle-test-event options event)Print out a test report event.
Print out a test report event.
(print-console-results results options)Render a set of test results out to the console.
Render a set of test results out to the console.
(write-html-results report-path results options)Render a set of test results to a human-friendly HTML file.
Render a set of test results to a human-friendly HTML file.
(write-junit-results report-path results options)Render a set of test results to a JUnit XML file.
Render a set of test results to a JUnit XML file.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |